﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Stimulsoft.Report;
using Stimulsoft.Report.Wpf;
using Stimulsoft.Report.WpfDesign;
using Stimulsoft.Base.Services;

namespace RibbonDesigner
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            StiOptions.Wpf.CurrentTheme = StiOptions.Wpf.Themes.Office2003BlueTheme;

            StiServiceContainer container = StiConfig.Services.GetServices(typeof(StiWpfToolbarService));
            foreach (StiService service in container)
            {
                if (service is StiWpfZoomToolbarService || service is StiWpfStatusBarService || service is StiWpfToolboxToolbarService)
                {
                    service.ServiceEnabled = true;
                }
                else
                {
                    service.ServiceEnabled = false;
                }
            }

            container = StiConfig.Services.GetServices(typeof(StiWpfMainMenuService));
            foreach (StiService service in container)
            {
                service.ServiceEnabled = false;
            }


            InitializeComponent();
            this.designerControl.RefreshDesigner += new EventHandler(designerControl_RefreshDesigner);
        }

        #region Handlers
        private void designerControl_RefreshDesigner(object sender, EventArgs e)
        {
            #region RefreshRibbonClipboard
            btCut.IsEnabled =
                StiActions.Clipboard.States.CanCut(designerControl) &&
                StiActions.Clipboard.States.GetClipboardEnabled(designerControl);

            btCopy.IsEnabled =
                StiActions.Clipboard.States.CanCopy(designerControl) &&
                StiActions.Clipboard.States.GetClipboardEnabled(designerControl);

            btPaste.IsEnabled =
                StiActions.Clipboard.States.CanPaste(designerControl) &&
                StiActions.Clipboard.States.GetClipboardEnabled(designerControl);

            btDelete.IsEnabled =
                StiActions.Clipboard.States.CanDelete(designerControl) &&
                StiActions.Clipboard.States.GetClipboardEnabled(designerControl);
            #endregion

            #region RefreshRibbonFont
            object fontObject = designerControl.Report != null ? designerControl.Report.GetCurrentPage().GetFont() : null;
            cbFontSize.IsEnabled = StiActions.Font.States.GetFontSizeEnabled(designerControl, fontObject);
            biFontBold.IsEnabled = StiActions.Font.States.GetFontBoldEnabled(designerControl, fontObject);
            biFontItalic.IsEnabled = StiActions.Font.States.GetFontItalicEnabled(designerControl, fontObject);
            biFontUnderline.IsEnabled = StiActions.Font.States.GetFontUnderlineEnabled(designerControl, fontObject);

            if (designerControl.Report != null)
            {
                cbFontSize.Text = StiActions.Font.States.GetFontSize(designerControl, fontObject).ToString();

                biFontBold.IsChecked = StiActions.Font.States.GetFontBoldChecked(designerControl, fontObject);
                biFontItalic.IsChecked = StiActions.Font.States.GetFontItalicChecked(designerControl, fontObject);
                biFontUnderline.IsChecked = StiActions.Font.States.GetFontUnderlineChecked(designerControl, fontObject);
            }
            #endregion
        }

        private void btCut_Click(object sender, RoutedEventArgs e)
        {
            StiActions.Clipboard.InvokeCut(designerControl);
        }

        private void btCopy_Click(object sender, RoutedEventArgs e)
        {
            StiActions.Clipboard.InvokeCopy(designerControl);
        }

        private void btDelete_Click(object sender, RoutedEventArgs e)
        {
            StiActions.Clipboard.InvokeDelete(designerControl);
        }

        private void RadComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            try
            {
                if (e.AddedItems.Count > 0)
                {
                    Telerik.Windows.Controls.RadComboBoxItem item = e.AddedItems[0] as Telerik.Windows.Controls.RadComboBoxItem;
                    float fontSize = float.Parse(item.Content.ToString());
                    StiActions.Font.InvokeFontSize(designerControl, fontSize);
                }
            }
            catch
            {
            }
        }

        private void btReportNew_Click(object sender, RoutedEventArgs e)
        {
            StiActions.MainMenu.InvokeReportNewBlank(designerControl);
        }

        private void btReportSave_Click(object sender, RoutedEventArgs e)
        {
            StiActions.MainMenu.InvokeReportSave(designerControl);
        }

        private void btReportOpen_Click(object sender, RoutedEventArgs e)
        {
            StiActions.MainMenu.InvokeReportOpen(designerControl);
        }

        private void biFontBold_Click(object sender, RoutedEventArgs e)
        {
            StiActions.Font.InvokeBold(designerControl, biFontBold.IsChecked.GetValueOrDefault());
        }

        private void biFontItalic_Click(object sender, RoutedEventArgs e)
        {
            StiActions.Font.InvokeItalic(designerControl, biFontItalic.IsChecked.GetValueOrDefault());
        }

        private void biFontUnderline_Click(object sender, RoutedEventArgs e)
        {
            StiActions.Font.InvokeUnderline(designerControl, biFontUnderline.IsChecked.GetValueOrDefault());
        }
        #endregion
    }
}